## ---------------------------------------------------------------------------
## PostProcessing.py
## Created: September, 2014
##
## MIrAD Post-Processing
## ---------------------------------------------------------------------------

## IMPORT SYSTEM MODULES
import sys, string, os, time

## CREATE THE GEOPROCESSOR OBJECT
try:
    import arcgisscripting
    gp = arcgisscripting.create()
except:
    import win32com.client
    gp = win32com.client.Dispatch("esriGeoprocessing.GpDispatch.1")

## CHECK OUT EXTENSION LICENSES
gp.CheckOutExtension("spatial")

## LOAD TOOLBOXES
## <<<Directory hard-coded notification>>>
gp.AddToolbox("C:/ArcGIS/ArcToolbox/Toolboxes/Spatial Analyst Tools.tbx")
gp.AddToolbox("C:/ArcGIS/ArcToolbox/Toolboxes/Data Management Tools.tbx")

## TIME VARIABLE
now = time.ctime()
print "Initiated MIrAD Post Processing Script"
print ""
print now
print ""

## TEMP DIRECTORY
## Define temp directory in python directory format (D:\\directory\\subdirectory\\...)
## <<<Directory hard-coded notification>>>
temp_py = "D:\\Drought\\MIrAD_US\\TEST_PYTHON_PP\\Temp\\"
## Create temp directory
os.system("mkdir " + str(temp_py))
print "Temp directory created:"
print str(temp_py)
print ""

## INPUT VARIABLES
## County Threshold - Path to county threshold output grid from primary script, "DynamicThresholdIdentification.py."
## <<<Directory hard-coded notification>>>
cntyTH = "D:\\Drought\\MIrAD_US\\2012_MIrAD_US_Final\\Irr2012_PostProcessing_CurrentV\\Scratch2012_v2\\cntyfips"
## Peak NDVI - Path to peak NDVI of target irrigation year.
## <<<Directory hard-coded notification>>>
pkNDVI = "D:\\Drought\\MIrAD_US\\Inputs\\Peak_NDVI\\Derived_From_eMODIS_smNDVI\\CellStats_MAXIMUM\\maxn12_m"
print "Input Variables-"
print "County Threshold Data: " + str(cntyTH)
print "Peak NDVI Data: " + str(pkNDVI)
print ""

## TEMP OUTPUT VARIABLES
## Post processing step 1 temp output.
temp_pp1 = str(temp_py) + "temp_pp1"
## Post processing step 2 temp output.
temp_pp2 = str(temp_py) + "temp_pp2"
## Post processing step 3 temp output.
temp_pp3 = str(temp_py) + "temp_pp3"

## FINAL OUTPUT VARIABLES
## Define final output name and destination directory.
## <<<Directory hard-coded notification>>>
MIrAD = "D:\\Drought\\MIrAD_US\\TEST_PYTHON_PP\\MIrAD_12"
print "MIrAD In Work:"
print str(MIrAD)
print ""

## POST PROCESSING STEP 1 - Check peak NDVI for relation to threshold.  If peak NDVI is greater than or equal to the
## threshold, set grid to 1.  If peak NDVI is less than threshold, set grid to 0.
print "Post Processing Step 1 in process..."
now = time.ctime()
print now
gp.SingleOutputMapAlgebra_sa("CON(" + str(pkNDVI) + " >= " + str(cntyTH) + ".NDVITHRABV, 1, 0)", temp_pp1, "")
now = time.ctime()
print now
print "Complete!"
print ""
## POST PROCESSING STEP 2 - Setup Grid for identifying single irrigated pixels.
print "Post Processing Step 2 in process..."
now = time.ctime()
print now
gp.FocalStatistics_sa(temp_pp1, temp_pp2, "Rectangle 3 3 CELL", "SUM", "DATA")
now = time.ctime()
print now
print "Complete!"
print ""
## POST PROCESSING STEP 3 - Remove single irrigated pixels.
print "Post Processing Step 3 in process..."
now = time.ctime()
print now
gp.SingleOutputMapAlgebra_sa("CON(" + str(temp_pp2) + " == 1, 0, " + str(temp_pp1) + ")", temp_pp3, "")
now = time.ctime()
print now
print "Complete!"
print ""
## POST PROCESSING STEP 4 - Set irrigated pixels to value 1 and non-irrigated pixels to value 0.
print "Post Processing Step 4 in process..."
now = time.ctime()
print now
gp.Reclassify_sa(temp_pp3, "VALUE", "0 0;1 1;NODATA 0", MIrAD, "DATA")
now = time.ctime()
print now
print "Complete!"
print ""
print "Temp Cleanup..."
os.system("rmdir " + str(temp_py) + "/s /q")
print "Complete!"
print ""
print "Post Processing Done."
